diff ac3dec.c @ 5967:15ed47af1838 libavcodec

Misc spelling fixes, prefer American over British English.
author diego
date Sun, 02 Dec 2007 15:43:08 +0000
parents ed3e9456f295
children 29635f7c3d9c
line wrap: on
line diff
--- a/ac3dec.c	Sun Dec 02 14:06:28 2007 +0000
+++ b/ac3dec.c	Sun Dec 02 15:43:08 2007 +0000
@@ -73,7 +73,7 @@
 /** dynamic range table. converts codes to scale factors. */
 static float dynrng_tab[256];
 
 /** dialogue normalization table */
 static float dialnorm_tab[32];
 
 /** Adjustments in dB gain */
@@ -161,7 +161,7 @@
     int out_channels;                       ///< number of output channels
 
     float downmix_coeffs[AC3_MAX_CHANNELS][2];  ///< stereo downmix coefficients
-    float dialnorm[2];                      ///< dialogue normalization
+    float dialnorm[2];                      ///< dialog normalization
     float dynrng[2];                        ///< dynamic range
     float cplco[AC3_MAX_CHANNELS][18];      ///< coupling coordinates
     int   ncplbnd;                          ///< number of coupling bands
@@ -276,7 +276,7 @@
         dynrng_tab[i] = powf(2.0f, v) * ((i & 0x1F) | 0x20);
     }
 
     /* generate dialogue normalization table
        references: Section 5.4.2.8 dialnorm
                    Section 7.6 Dialogue Normalization */
     for(i=1; i<32; i++) {
@@ -382,7 +382,7 @@
     /* read the rest of the bsi. read twice for dual mono mode. */
     i = !(ctx->acmod);
     do {
-        ctx->dialnorm[i] = dialnorm_tab[get_bits(gb, 5)]; // dialogue normalization
+        ctx->dialnorm[i] = dialnorm_tab[get_bits(gb, 5)]; // dialog normalization
         if (get_bits1(gb))
             skip_bits(gb, 8); //skip compression
         if (get_bits1(gb))
@@ -73,7 +73,7 @@
 static float dynrng_tab[256];
 
-/** dialogue normalization table */
+/** dialog normalization table */
 static float dialnorm_tab[32];
 
@@ -276,7 +276,7 @@
     }
 
-    /* generate dialogue normalization table
+    /* generate dialog normalization table
        references: Section 5.4.2.8 dialnorm
                    Section 7.6 Dialogue Normalization */